﻿using Infragistics.Windows;
using Infragistics.Windows.DataPresenter;
using Infragistics.Windows.DataPresenter.Events;
using Infragistics.Windows.Editors;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Diagnostics;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Controls.Primitives;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace XamEditorsApp
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private ObservableCollection<TestData> testDatas;
        private bool shouldUpdateCellValue;        
        private string editorText;

        public MainWindow()
        {
            InitializeComponent();

            this.testDatas = new ObservableCollection<TestData> {
                new TestData { Mileage = 123 },
                new TestData { Mileage = 500 }
            };

            this.DataContext = this;                  
        }        

        public ObservableCollection<TestData> TestDatas
        {
            get
            {
                return this.testDatas;
            }

            set
            {
                if (this.testDatas != null)
                {
                    this.testDatas = value;
                }
            }
        }
        
        private void dataGrid_CellUpdating(object sender, Infragistics.Windows.DataPresenter.Events.CellUpdatingEventArgs e)
        {                    
            if (this.shouldUpdateCellValue == false)
            {
                e.Cancel = true;               
            }

            this.shouldUpdateCellValue = false;
        }

        private void XamNumericEditor_PreviewKeyDown(object sender, KeyEventArgs e)
        {            
            if (e.Key == Key.Enter)
            {
                this.shouldUpdateCellValue = true;
                this.editorText = (sender as XamNumericEditor).Text;
                this.UpdateValue(sender as XamNumericEditor);
            }
            else
            {
                this.shouldUpdateCellValue = false;
            }
        }

        private void XamNumericEditor_PreviewMouseLeftButtonDown(object sender, MouseButtonEventArgs e)
        {                    
            RepeatButton spinButton = e.Source as RepeatButton;
            if (e.Source is RepeatButton || e.Source is Border)
            {
                this.shouldUpdateCellValue = true;             
            }
        }

        private void XamNumericEditor_EditModeEnding(object sender, Infragistics.Windows.Editors.Events.EditModeEndingEventArgs e)
        {            
           this.editorText = (sender as XamNumericEditor).Text;
        }        

        private void XamNumericEditor_EditModeEnded(object sender, Infragistics.Windows.Editors.Events.EditModeEndedEventArgs e)
        {            
            this.shouldUpdateCellValue = true;
            this.UpdateValue(sender as XamNumericEditor);
        }     
                
        private void UpdateValue(XamNumericEditor editor)
        {                                    
            editor.SetCurrentValue(XamNumericEditor.ValueProperty, double.Parse(this.editorText));
        }        
    }

    public class TestData : INotifyPropertyChanged
    {
        private double mileage;
        public double Mileage
        {
            get { return mileage; }
            set
            {
                mileage = value;
                NotifyPropertyChanged("Mileage");
            }
        }

        public event PropertyChangedEventHandler PropertyChanged;

        private void NotifyPropertyChanged(String info)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(info));
            }
        }
    }
}